home | help
GMX-TRAJ(1)			     GROMACS			     GMX-TRAJ(1)

NAME
     gmx-traj  -  Plot x, v, f, box, temperature and rotational energy from tra-
     jectories

SYNOPSIS
	gmx traj [-f [<.xtc/.trr/...>]] [-s [<.tpr/.gro/...>]] [-n [<.ndx>]]
		 [-ox [<.xvg>]] [-oxt [<.xtc/.trr/...>]] [-ov [<.xvg>]]
		 [-of [<.xvg>]] [-ob [<.xvg>]] [-ot [<.xvg>]] [-ekt [<.xvg>]]
		 [-ekr [<.xvg>]] [-vd [<.xvg>]] [-cv [<.pdb>]] [-cf [<.pdb>]]
		 [-av [<.xvg>]] [-af [<.xvg>]] [-b <time>] [-e <time>]
		 [-dt <time>] [-tu <enum>] [-[no]w] [-xvg <enum>] [-[no]com]
		 [-[no]pbc] [-[no]mol] [-[no]nojump] [-[no]x] [-[no]y]
		 [-[no]z] [-ng <int>] [-[no]len] [-[no]fp] [-bin <real>]
		 [-ctime <real>] [-scale <real>]

DESCRIPTION
     gmx traj plots coordinates, velocities, forces and/or the box.   With  -com
     the  coordinates,	velocities  and  forces are calculated for the center of
     mass of each group.  When -mol is set, the numbers in the	index  file  are
     interpreted as molecule numbers and the same procedure as with -com is used
     for each molecule.

     Option  -ot  plots  the  temperature of each group, provided velocities are
     present in the trajectory file.  No corrections are  made	for  constrained
     degrees of freedom!  This implies -com.

     Options  -ekt and -ekr plot the translational and rotational kinetic energy
     of each group, provided velocities are  present  in  the  trajectory  file.
     This implies -com.

     Options -cv and -cf write the average velocities and average forces as tem-
     perature factors to a .pdb file with the average coordinates or the coordi-
     nates  at -ctime.	The temperature factors are scaled such that the maximum
     is 10.  The scaling can be changed with the option -scale.  To get the  ve-
     locities  or  forces of one frame set both -b and -e to the time of desired
     frame. When averaging over frames you might need to use the -nojump  option
     to  obtain  the correct average coordinates.  If you select either of these
     option the average force and velocity for each atom are written to an  .xvg
     file as well (specified with -av or -af).

     Option -vd computes a velocity distribution, i.e. the norm of the vector is
     plotted.  In  addition in the same graph the kinetic energy distribution is
     given.

     See gmx trajectory for plotting similar data for selections.

OPTIONS
     Options to specify input files:

     -f [<.xtc/.trr/...>] (traj.xtc)
	    Trajectory: xtc trr cpt gro g96 pdb tng h5md

     -s [<.tpr/.gro/...>] (topol.tpr)
	    Structure+mass(db): tpr gro g96 pdb brk ent

     -n [<.ndx>] (index.ndx) (Optional)
	    Index file

     Options to specify output files:

     -ox [<.xvg>] (coord.xvg) (Optional)
	    xvgr/xmgr file

     -oxt [<.xtc/.trr/...>] (coord.xtc) (Optional)
	    Trajectory: xtc trr cpt gro g96 pdb tng h5md

     -ov [<.xvg>] (veloc.xvg) (Optional)
	    xvgr/xmgr file

     -of [<.xvg>] (force.xvg) (Optional)
	    xvgr/xmgr file

     -ob [<.xvg>] (box.xvg) (Optional)
	    xvgr/xmgr file

     -ot [<.xvg>] (temp.xvg) (Optional)
	    xvgr/xmgr file

     -ekt [<.xvg>] (ektrans.xvg) (Optional)
	    xvgr/xmgr file

     -ekr [<.xvg>] (ekrot.xvg) (Optional)
	    xvgr/xmgr file

     -vd [<.xvg>] (veldist.xvg) (Optional)
	    xvgr/xmgr file

     -cv [<.pdb>] (veloc.pdb) (Optional)
	    Protein data bank file

     -cf [<.pdb>] (force.pdb) (Optional)
	    Protein data bank file

     -av [<.xvg>] (all_veloc.xvg) (Optional)
	    xvgr/xmgr file

     -af [<.xvg>] (all_force.xvg) (Optional)
	    xvgr/xmgr file

     Other options:

     -b <time> (0)
	    Time of first frame to read from trajectory (default unit ps)

     -e <time> (0)
	    Time of last frame to read from trajectory (default unit ps)

     -dt <time> (0)
	    Only use frame when t MOD dt = first time (default unit ps)

     -tu <enum> (ps)
	    Unit for time values: fs, ps, ns, us, ms, s

     -[no]w (no)
	    View output .xvg, .xpm, .eps and .pdb files

     -xvg <enum> (xmgrace)
	    xvg plot formatting: xmgrace, xmgr, none

     -[no]com (no)
	    Plot data for the com of each group

     -[no]pbc (yes)
	    Make molecules whole for COM

     -[no]mol (no)
	    Index contains molecule numbers instead of atom numbers

     -[no]nojump (no)
	    Remove jumps of atoms across the box

     -[no]x (yes)
	    Plot X-component

     -[no]y (yes)
	    Plot Y-component

     -[no]z (yes)
	    Plot Z-component

     -ng <int> (1)
	    Number of groups to consider

     -[no]len (no)
	    Plot vector length

     -[no]fp (no)
	    Full precision output

     -bin <real> (1)
	    Binwidth for velocity histogram (nm/ps)

     -ctime <real> (-1)
	    Use frame at this time for x in -cv and -cf instead of the average x

     -scale <real> (0)
	    Scale factor for .pdb output, 0 is autoscale

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			     GMX-TRAJ(1)

home | help